@@ -1,8 +1,9 @@
-#!/bin/sh -e
+#!/bin/sh
 set -o errexit
 
 ###
-# Copyright (c) 2015-2020, Antoine "vv221/vv222" Le Gonidec
+# Copyright (c) 2015-2021, Antoine Le Gonidec <vv221@dotslashplay.it>
+# Copyright (c) 2016-2021, Mopi
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -30,40 +31,45 @@ set -o errexit
 
 ###
 # Anna's Quest
-# build native Linux packages from the original installers
-# send your bug reports to vv221@dotslashplay.it
+# build native packages from the original installers
+# send your bug reports to contact@dotslashplay.it
 ###
 
-script_version=20200918.1
+script_version=20210502.6
 
 # Set game-specific variables
 
 GAME_ID='annas-quest'
-# shellcheck disable=SC1112
-GAME_NAME='Anna’s Quest'
+GAME_NAME='Annaʼs Quest'
 
-ARCHIVES_LIST='ARCHIVE_GOG'
+ARCHIVES_LIST='
+ARCHIVE_BASE_1
+ARCHIVE_BASE_0'
 
-ARCHIVE_GOG='gog_anna_s_quest_2.1.0.3.sh'
-ARCHIVE_GOG_URL='https://www.gog.com/game/annas_quest'
-ARCHIVE_GOG_MD5='cb4cf167a13413b6df8238397393298a'
-ARCHIVE_GOG_SIZE='1100000'
-ARCHIVE_GOG_VERSION='1.0.0202-gog2.1.0.3'
+ARCHIVE_BASE_1='anna_s_quest_1_1_0214_27877.sh'
+ARCHIVE_BASE_1_MD5='48fd7d6c2a8a519a227cbf604392109b'
+ARCHIVE_BASE_1_TYPE='mojosetup'
+ARCHIVE_BASE_1_SIZE='1200000'
+ARCHIVE_BASE_1_VERSION='1.1.0214-gog27877'
+ARCHIVE_BASE_1_URL='https://www.gog.com/game/annas_quest'
 
-ARCHIVE_DOC1_PATH='data/noarch/docs'
-ARCHIVE_DOC1_FILES='./*'
+ARCHIVE_BASE_0='gog_anna_s_quest_2.1.0.3.sh'
+ARCHIVE_BASE_0_MD5='cb4cf167a13413b6df8238397393298a'
+ARCHIVE_BASE_0_TYPE='mojosetup'
+ARCHIVE_BASE_0_SIZE='1100000'
+ARCHIVE_BASE_0_VERSION='1.0.0202-gog2.1.0.3'
 
-ARCHIVE_DOC2_PATH='data/noarch/game/documents/licenses'
-ARCHIVE_DOC2_FILES='./*'
+ARCHIVE_DOC_DATA_PATH='data/noarch/game/documents'
+ARCHIVE_DOC_DATA_FILES='*'
 
 ARCHIVE_GAME_BIN_PATH='data/noarch/game'
-ARCHIVE_GAME_BIN_FILES='./anna ./config.ini ./libs64'
+ARCHIVE_GAME_BIN_FILES='anna config.ini libs64/libavcodec.so.56 libs64/libavdevice.so.56 libs64/libavfilter.so.5 libs64/libavformat.so.56 libs64/libavutil.so.54 libs64/libswresample.so.1 libs64/libswscale.so.3'
 
 ARCHIVE_GAME_VIDEO_PATH='data/noarch/game'
-ARCHIVE_GAME_VIDEO_FILES='./videos'
+ARCHIVE_GAME_VIDEO_FILES='videos'
 
 ARCHIVE_GAME_DATA_PATH='data/noarch/game'
-ARCHIVE_GAME_DATA_FILES='./characters ./data.vis ./lua ./scenes'
+ARCHIVE_GAME_DATA_FILES='characters data.vis lua scenes'
 
 CONFIG_FILES='./config.ini'
 
@@ -71,7 +77,6 @@ APP_MAIN_TYPE='native'
 APP_MAIN_EXE='anna'
 APP_MAIN_LIBS='libs64'
 APP_MAIN_ICON='data/noarch/support/icon.png'
-APP_MAIN_ICON_RES='256'
 
 PACKAGES_LIST='PKG_VIDEO PKG_DATA PKG_BIN'
 
@@ -82,21 +87,19 @@ PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
 PKG_BIN_ARCH='64'
-PKG_BIN_DEPS_DEB="$PKG_VIDEO_ID, $PKG_DATA_ID, libgl1-mesa-glx | libgl1, libopenal1"
-PKG_BIN_DEPS_ARCH="$PKG_VIDEO_ID $PKG_DATA_ID libgl openal"
+PKG_BIN_DEPS="${PKG_VIDEO_ID} ${PKG_DATA_ID} glibc libstdc++ glx openal libz.so.1"
 
 # Load common functions
 
-target_version='2.4'
+target_version='2.12'
 
 if [ -z "$PLAYIT_LIB2" ]; then
-	: "${XDG_DATA_HOME:="$HOME/.local/share"}"
-	for path in\
-		"$PWD"\
-		"$XDG_DATA_HOME/play.it"\
-		'/usr/local/share/games/play.it'\
-		'/usr/local/share/play.it'\
-		'/usr/share/games/play.it'\
+	for path in \
+		"$PWD" \
+		"${XDG_DATA_HOME:="$HOME/.local/share"}/play.it" \
+		'/usr/local/share/games/play.it' \
+		'/usr/local/share/play.it' \
+		'/usr/share/games/play.it' \
 		'/usr/share/play.it'
 	do
 		if [ -e "$path/libplayit2.sh" ]; then
@@ -110,31 +113,27 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
-#shellcheck source=play.it-2/lib/libplayit2.sh
+# shellcheck source=play.it-2/lib/libplayit2.sh
 . "$PLAYIT_LIB2"
 
 # Extract game data
 
 extract_data_from "$SOURCE_ARCHIVE"
+prepare_package_layout
 
-PKG='PKG_BIN'
-organize_data 'GAME_BIN' "$PATH_GAME"
-
-PKG='PKG_VIDEO'
-organize_data 'GAME_VIDEO' "$PATH_GAME"
+# Get game icon
 
 PKG='PKG_DATA'
-organize_data 'DOC1'      "$PATH_DOC"
-organize_data 'DOC2'      "$PATH_DOC"
-organize_data 'GAME_DATA' "$PATH_GAME"
-get_icon_from_temp_dir 'APP_MAIN'
+icons_get_from_workdir 'APP_MAIN'
 
-rm --recursive "$PLAYIT_WORKDIR/gamedata"
+# Clean up temporary files
+
+rm --recursive "${PLAYIT_WORKDIR}/gamedata"
 
 # Write launchers
 
 PKG='PKG_BIN'
-write_launcher 'APP_MAIN'
+launchers_write 'APP_MAIN'
 
 # Build package
 
