@@ -1,8 +1,10 @@
-#!/bin/sh -e
+#!/bin/sh
 set -o errexit
 
 ###
-# Copyright (c) 2015-2020, Antoine "vv221/vv222" Le Gonidec
+# Copyright (c) 2015-2021, Antoine Le Gonidec <vv221@dotslashplay.it>
+# Copyright (c) 2016-2021, Mopi
+# Copyright (c) 2020-2021, Hubert Ray
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -30,11 +32,11 @@ set -o errexit
 
 ###
 # Worms Armageddon
-# build native Linux packages from the original installers
+# build native packages from the original installers
 # send your bug reports to contact@dotslashplay.it
 ###
 
-script_version=20200929.3
+script_version=20210404.5
 
 # Set game-specific variables
 
@@ -42,12 +44,18 @@ GAME_ID='worms-armageddon'
 GAME_NAME='Worms Armageddon'
 
 ARCHIVES_LIST='
+ARCHIVE_GOG_3
 ARCHIVE_GOG_2
 ARCHIVE_GOG_1
 ARCHIVE_GOG_0'
 
+ARCHIVE_GOG_3='setup_worms_armageddon_gog-3.8.1_(43454).exe'
+ARCHIVE_GOG_3_URL='https://www.gog.com/game/worms_armageddon'
+ARCHIVE_GOG_3_MD5='f84e60ba11363219c582a4ff65301692'
+ARCHIVE_GOG_3_VERSION='3.8.1-gog43454'
+ARCHIVE_GOG_3_SIZE='650000'
+
 ARCHIVE_GOG_2='setup_worms_armageddon_gog-2_(40354).exe'
-ARCHIVE_GOG_2_URL='https://www.gog.com/game/worms_armageddon'
 ARCHIVE_GOG_2_MD5='db2087029ee8c069c9006ebeedc76bbf'
 ARCHIVE_GOG_2_VERSION='3.8-gog40354'
 ARCHIVE_GOG_2_SIZE='650000'
@@ -63,52 +71,49 @@ ARCHIVE_GOG_0_VERSION='3.7.2.1-gog2.0.0.2'
 ARCHIVE_GOG_0_SIZE='570000'
 
 ARCHIVE_DOC_DATA_PATH='.'
-ARCHIVE_DOC_DATA_FILES='./wa_manual.pdf ./worms?armageddon?update?documentation.rtf'
+ARCHIVE_DOC_DATA_FILES='wa_manual.pdf worms?armageddon?update?documentation.rtf'
 
 ARCHIVE_GAME_BIN_PATH='.'
-ARCHIVE_GAME_BIN_FILES='./lfbmp10n.dll ./lfcmp10n.dll ./lflmb10n.dll ./lftga10n.dll ./ltfil10n.dll ./ltkrn10n.dll ./wa.exe user/bankeditor.exe ./steam_api.dll'
+ARCHIVE_GAME_BIN_FILES='*.dll wa.exe user/bankeditor.exe'
 
 ARCHIVE_GAME_DATA_PATH='.'
-ARCHIVE_GAME_DATA_FILES='./data ./fesfx ./graphics ./tweaks user/fanfare user/flags user/graves user/import user/names.wdb user/savedlevels user/schemes user/speech user/teams'
+ARCHIVE_GAME_DATA_FILES='data fesfx graphics tweaks user'
 
-ARCHIVE_GAME_DATA_SAVE_PATH='./__support'
-ARCHIVE_GAME_DATA_SAVE_FILES='./save'
-
-# Keep compatibility with old archives
-ARCHIVE_DOC_DATA_PATH_GOG_0='app'
-ARCHIVE_GAME_BIN_PATH_GOG_0='app'
-ARCHIVE_GAME_DATA_PATH_GOG_0='app'
-ARCHIVE_GAME_DATA_SAVE_PATH_GOG_0='app/__support'
+ARCHIVE_GAME0_DATA_PATH='__support'
+ARCHIVE_GAME0_DATA_FILES='save'
 
 DATA_DIRS='./save ./user'
+DATA_FILES='./graphics/font.bmp'
 
 APP_MAIN_TYPE='wine'
 APP_MAIN_EXE='wa.exe'
 APP_MAIN_ICON='wa.exe'
-APP_MAIN_ICON_RES='16 32 48'
-APP_MAIN_PRERUN='# Create required empty file prior to game run
-touch steam.dat'
-
 PACKAGES_LIST='PKG_BIN PKG_DATA'
 
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
 PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID wine"
+PKG_BIN_DEPS="${PKG_DATA_ID} wine"
+
+# Keep compatibility with old archives
+
+ARCHIVE_DOC_DATA_PATH_GOG_0='app'
+ARCHIVE_GAME_BIN_PATH_GOG_0='app'
+ARCHIVE_GAME_DATA_PATH_GOG_0='app'
+ARCHIVE_GAME0_DATA_PATH_GOG_0='app/__support'
 
 # Load common functions
 
-target_version='2.3'
+target_version='2.12'
 
 if [ -z "$PLAYIT_LIB2" ]; then
-	: "${XDG_DATA_HOME:="$HOME/.local/share"}"
-	for path in\
-		"$PWD"\
-		"$XDG_DATA_HOME/play.it"\
-		'/usr/local/share/games/play.it'\
-		'/usr/local/share/play.it'\
-		'/usr/share/games/play.it'\
+	for path in \
+		"$PWD" \
+		"${XDG_DATA_HOME:="$HOME/.local/share"}/play.it" \
+		'/usr/local/share/games/play.it' \
+		'/usr/local/share/play.it' \
+		'/usr/share/games/play.it' \
 		'/usr/share/play.it'
 	do
 		if [ -e "$path/libplayit2.sh" ]; then
@@ -122,31 +127,37 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
-#shellcheck source=play.it-2/lib/libplayit2.sh
+# shellcheck source=play.it-2/lib/libplayit2.sh
 . "$PLAYIT_LIB2"
 
 # Extract game data
 
 extract_data_from "$SOURCE_ARCHIVE"
-
-for PKG in $PACKAGES_LIST; do
-	organize_data "DOC_${PKG#PKG_}"  "$PATH_DOC"
-	organize_data "GAME_${PKG#PKG_}" "$PATH_GAME"
-done
-
+prepare_package_layout
 PKG='PKG_DATA'
 organize_data "GAME_DATA_SAVE"  "$PATH_GAME"
 
-PKG='PKG_BIN'
-extract_and_sort_icons_from 'APP_MAIN'
-move_icons_to 'PKG_DATA'
+# Get game icon
 
-rm --recursive "$PLAYIT_WORKDIR/gamedata"
+PKG='PKG_BIN'
+icons_get_from_package 'APP_MAIN'
+icons_move_to 'PKG_DATA'
+
+# Clean up temporary files
+
+rm --recursive "${PLAYIT_WORKDIR}/gamedata"
+
+# Create required empty file prior to game run
+
+APP_MAIN_PRERUN="$APP_MAIN_PRERUN"'
+
+# Create required empty file prior to game run
+touch steam.dat'
 
 # Write launchers
 
 PKG='PKG_BIN'
-write_launcher 'APP_MAIN'
+launchers_write 'APP_MAIN'
 
 # Build package
 
