@@ -1,30 +1,35 @@
 # update dependencies list with commands needed for icons extraction
 # USAGE: icons_list_dependencies
+# RETURNS: nothing
+# SIDE EFFECT: export $ICONS_DEPS, a variable including a space-separated list of required commands to handle the icons of the current game
 icons_list_dependencies() {
 	# Do nothing if the calling script explicitely asked for skipping icons extraction
 	[ $SKIP_ICONS -eq 1 ] && return 0
 
 	local script
 	script="$0"
-	if grep\
-		--regexp="^APP_[^_]\\+_ICON='.\\+'"\
-		--regexp="^APP_[^_]\\+_ICON_.\\+='.\\+'"\
-		"$script" 1>/dev/null
+	if grep \
+		--quiet \
+		--regexp="^APP_[^_]\\+_ICON='.\\+'" \
+		--regexp="^APP_[^_]\\+_ICON_.\\+='.\\+'" \
+		"$script"
 	then
 		ICONS_DEPS="$ICONS_DEPS identify"
-		if grep\
-			--regexp="^APP_[^_]\\+_ICON='.\\+\\.bmp'"\
-			--regexp="^APP_[^_]\\+_ICON_.\\+='.\\+\\.bmp'"\
-			--regexp="^APP_[^_]\\+_ICON='.\\+\\.ico'"\
-			--regexp="^APP_[^_]\\+_ICON_.\\+='.\\+\\.ico'"\
-			"$script" 1>/dev/null
+		if grep \
+			--quiet \
+			--regexp="^APP_[^_]\\+_ICON='.\\+\\.bmp'" \
+			--regexp="^APP_[^_]\\+_ICON_.\\+='.\\+\\.bmp'" \
+			--regexp="^APP_[^_]\\+_ICON='.\\+\\.ico'" \
+			--regexp="^APP_[^_]\\+_ICON_.\\+='.\\+\\.ico'" \
+			"$script"
 		then
 			ICONS_DEPS="$ICONS_DEPS convert"
 		fi
-		if grep\
-			--regexp="^APP_[^_]\\+_ICON='.\\+\\.exe'"\
-			--regexp="^APP_[^_]\\+_ICON_.\\+='.\\+\\.exe'"\
-			"$script" 1>/dev/null
+		if grep \
+			--quiet \
+			--regexp="^APP_[^_]\\+_ICON='.\\+\\.exe'" \
+			--regexp="^APP_[^_]\\+_ICON_.\\+='.\\+\\.exe'" \
+			"$script"
 		then
 			ICONS_DEPS="$ICONS_DEPS convert wrestool"
 		fi
@@ -34,26 +39,29 @@ icons_list_dependencies() {
 
 # get .png file(s) from various icon sources in current package
 # USAGE: icons_get_from_package $app[…]
-# NEEDED VARS: APP_ID|GAME_ID PATH_GAME PATH_ICON_BASE PLAYIT_WORKDIR PKG
-# CALLS: icons_get_from_path
+# RETURNS: nothing
+# SIDE EFFECT: get original icon files from the current package,
+#              convert them to standard icon formats,
+#              and include the standard icons in the current package
 icons_get_from_package() {
 	# Do nothing if the calling script explicitely asked for skipping icons extraction
 	[ $SKIP_ICONS -eq 1 ] && return 0
 
+	# get the current package
+	local package
+	package=$(package_get_current)
+
 	local path
-	local path_pkg
-	path_pkg="$(get_value "${PKG}_PATH")"
-	if [ -z "$path_pkg" ]; then
-		error_invalid_argument 'PKG' 'icons_get_from_package'
-	fi
-	path="${path_pkg}${PATH_GAME}"
+	path="$(package_get_path "$package")${PATH_GAME}"
 	icons_get_from_path "$path" "$@"
 }
 
 # get .png file(s) from various icon sources in temporary work directory
-# USAGE: icons_get_from_package $app[…]
-# NEEDED VARS: APP_ID|GAME_ID PATH_ICON_BASE PLAYIT_WORKDIR PKG
-# CALLS: icons_get_from_path
+# USAGE: icons_get_from_workdir $app[…]
+# RETURNS: nothing
+# SIDE EFFECT: get original icon files from ./play.it temporary directory,
+#              convert them to standard icon formats,
+#              and include the standard icons in the current package
 icons_get_from_workdir() {
 	# Do nothing if the calling script explicitely asked for skipping icons extraction
 	[ $SKIP_ICONS -eq 1 ] && return 0
@@ -65,8 +73,10 @@ icons_get_from_workdir() {
 
 # get .png file(s) from various icon sources
 # USAGE: icons_get_from_path $directory $app[…]
-# NEEDED VARS: APP_ID|GAME_ID PATH_ICON_BASE PLAYIT_WORKDIR PKG
-# CALLS: icon_extract_png_from_file icons_include_png_from_directory testvar
+# RETURNS: nothing
+# SIDE EFFECT: get original icon files from the given directory,
+#              convert them to standard icon formats,
+#              and include the standard icons in the current package
 icons_get_from_path() {
 	local app
 	local destination
@@ -74,15 +84,15 @@ icons_get_from_path() {
 	local file
 	local icon
 	local list
-	local path_pkg
 	local wrestool_id
+
+	# get the current package
+	local package
+	package=$(package_get_current)
+
 	directory="$1"
 	shift 1
 	destination="$PLAYIT_WORKDIR/icons"
-	path_pkg="$(get_value "${PKG}_PATH")"
-	if [ -z "$path_pkg" ]; then
-		error_invalid_argument 'PKG' 'icons_get_from_package'
-	fi
 	for app in "$@"; do
 		if ! testvar "$app" 'APP'; then
 			error_invalid_argument 'app' 'icons_get_from_package'
@@ -95,9 +105,10 @@ icons_get_from_path() {
 			if [ -z "$file" ]; then
 				error_variable_not_set 'icons_get_from_path' '$'"$icon"
 			fi
-			if [ $DRY_RUN -eq 0 ] && [ ! -f "$directory/$file" ]; then
-				error_icon_file_not_found "$directory/$file"
-			fi
+
+			# Check icon file existence
+			file=$(icon_check_file_existence "$directory" "$file")
+
 			wrestool_id="$(get_value "${icon}_ID")"
 			icon_extract_png_from_file "$directory/$file" "$destination"
 			icons_include_png_from_directory "$app" "$destination"
@@ -105,10 +116,40 @@ icons_get_from_path() {
 	done
 }
 
+# check icon file existence
+# USAGE: icon_check_file_existence $directory $file
+# RETURNS: $file or throws an error
+icon_check_file_existence() {
+	# shellcheck disable=SC2039
+	local directory file
+	directory="$1"
+	file="$2"
+
+	# Return early in dry-run mode
+	if [ $DRY_RUN -eq 1 ]; then
+		printf '%s' "$file"
+		return 0
+	fi
+
+	if [ ! -f "$directory/$file" ]; then
+		# pre-2.8 scripts could use globbing in file path
+		# shellcheck disable=SC2154
+		if version_is_at_least '2.8' "$target_version"; then
+			error_icon_file_not_found "$directory/$file"
+			return 1
+		else
+			file=$(icon_check_file_existence_pre_2_8 "$directory" "$file")
+		fi
+	fi
+
+	printf '%s' "$file"
+	return 0
+}
+
 # extract .png file(s) from target file
 # USAGE: icon_extract_png_from_file $file $destination
-# CALLS: icon_convert_bmp_to_png icon_extract_png_from_exe icon_extract_png_from_ico icon_copy_png
-# CALLED BY: icons_get_from_path
+# RETURNS: nothing
+# SIDE EFFECT: convert the given file to .png icons, the .png files are created in the given directory
 icon_extract_png_from_file() {
 	local destination
 	local extension
@@ -138,8 +179,8 @@ icon_extract_png_from_file() {
 
 # extract .png file(s) for .exe
 # USAGE: icon_extract_png_from_exe $file $destination
-# CALLS: icon_extract_ico_from_exe icon_extract_png_from_ico
-# CALLED BY: icon_extract_png_from_file
+# RETURNS: nothing
+# SIDE EFFECT: extract .png icons from the given .exe file, the .png files are created in the given directory
 icon_extract_png_from_exe() {
 	[ "$DRY_RUN" -eq 1 ] && return 0
 	local destination
@@ -155,7 +196,8 @@ icon_extract_png_from_exe() {
 
 # extract .ico file(s) from .exe
 # USAGE: icon_extract_ico_from_exe $file $destination
-# CALLED BY: icon_extract_png_from_exe
+# RETURNS: nothing
+# SIDE EFFECT: extract .ico icons from the given .exe file, the .ico files are created in the given directory
 icon_extract_ico_from_exe() {
 	[ "$DRY_RUN" -eq 1 ] && return 0
 	local destination
@@ -164,22 +206,26 @@ icon_extract_ico_from_exe() {
 	file="$1"
 	destination="$2"
 	[ "$wrestool_id" ] && options="--name=$wrestool_id"
+	debug_external_command "wrestool --extract --type=14 $options --output=\"$destination\" \"$file\" 2>/dev/null"
 	wrestool --extract --type=14 $options --output="$destination" "$file" 2>/dev/null
 }
 
 # convert .bmp file to .png
 # USAGE: icon_convert_bmp_to_png $file $destination
-# CALLED BY: icon_extract_png_from_file
+# RETURNS: nothing
+# SIDE EFFECT: convert the given .bmp file to .png, the .png file is created in the given directory
 icon_convert_bmp_to_png() { icon_convert_to_png "$@"; }
 
 # extract .png file(s) from .ico
 # USAGE: icon_extract_png_from_ico $file $destination
-# CALLED BY: icon_extract_png_from_file icon_extract_png_from_exe
+# RETURNS: nothing
+# SIDE EFFECT: convert the given .ico file to .png, the .png files are created in the given directory
 icon_extract_png_from_ico() { icon_convert_to_png "$@"; }
 
 # convert multiple icon formats to .png
 # USAGE: icon_convert_to_png $file $destination
-# CALLED BY: icon_extract_png_from_bmp icon_extract_png_from_ico
+# RETURNS: nothing
+# SIDE EFFECT: convert the given image file to .png, the .png files are created in the given directory
 icon_convert_to_png() {
 	[ "$DRY_RUN" -eq 1 ] && return 0
 	local destination
@@ -188,12 +234,14 @@ icon_convert_to_png() {
 	file="$1"
 	destination="$2"
 	name="$(basename "$file")"
+	debug_external_command "convert \"$file\" \"$destination/${name%.*}.png\""
 	convert "$file" "$destination/${name%.*}.png"
 }
 
 # copy .png file to directory
 # USAGE: icon_copy_png $file $destination
-# CALLED BY: icon_extract_png_from_file
+# RETURNS: nothing
+# SIDE EFFECT: copy the given .png file to the given directory
 icon_copy_png() {
 	[ "$DRY_RUN" -eq 1 ] && return 0
 	local destination
@@ -205,9 +253,8 @@ icon_copy_png() {
 
 # get .png file(s) from target directory and put them in current package
 # USAGE: icons_include_png_from_directory $app $directory
-# NEEDED VARS: APP_ID|GAME_ID PATH_ICON_BASE PKG
-# CALLS: icon_get_resolution_from_file
-# CALLED BY: icons_get_from_path
+# RETURNS: nothing
+# SIDE EFFECT: take the icons from the given directory, move them to standard paths into the current package
 icons_include_png_from_directory() {
 	[ "$DRY_RUN" -eq 1 ] && return 0
 	local app
@@ -215,25 +262,29 @@ icons_include_png_from_directory() {
 	local file
 	local path
 	local path_icon
-	local path_pkg
 	local resolution
+
+	# get the current package
+	local package
+	package=$(package_get_current)
+
 	app="$1"
 	directory="$2"
 	name="$(get_value "${app}_ID")"
 	[ -n "$name" ] || name="$GAME_ID"
-	path_pkg="$(get_value "${PKG}_PATH")"
-	if [ -z "$path_pkg" ]; then
-		error_invalid_argument 'PKG' 'icons_include_png_from_directory'
-	fi
 	for file in "$directory"/*.png; do
 		icon_get_resolution_from_file "$file"
 		path_icon="$PATH_ICON_BASE/$resolution/apps"
-		path="${path_pkg}${path_icon}"
+		path="$(package_get_path "$package")${path_icon}"
 		mkdir --parents "$path"
 		mv "$file" "$path/$name.png"
 	done
 }
-# comaptibility alias
+# compatibility alias
+###
+# TODO
+# This function should be moved to the compatibility aliases source file
+###
 sort_icons() {
 	local app
 	local directory
@@ -245,93 +296,43 @@ sort_icons() {
 
 # get image resolution for target file, exported as $resolution
 # USAGE: icon_get_resolution_from_file $file
-# CALLED BY: icons_include_png_from_directory
+# RETURNS: nothing
+# SIDE EFFECT: export the resolution of the given file as $resolution, using the format "${width}x${height}"
 icon_get_resolution_from_file() {
 	local file
 	file="$1"
-	if version_target_is_older_than '2.8' && [ -n "${file##* *}" ]; then
+
+	# `identify` should be available when this function is called.
+	# Exits with an explicit error if it is missing
+	if ! command -v 'identify' >/dev/null 2>&1; then
+		error_unavailable_command 'icon_get_resolution_from_file' 'identify'
+	fi
+
+	if ! version_is_at_least '2.8' "$target_version" && [ -n "${file##* *}" ]; then
 		field=2
 		unset resolution
-		while [ -z "$resolution" ] || [ -n "$(printf '%s' "$resolution" | sed 's/[0-9]*x[0-9]*//')" ]; do
+		while
+			[ -z "$resolution" ] || \
+			[ -n "$(printf '%s' "$resolution" | sed 's/[0-9]*x[0-9]*//')" ]
+		do
 			resolution="$(identify $file | sed "s;^$file ;;" | cut --delimiter=' ' --fields=$field)"
+			resolution="${resolution%+0+0}"
 			field=$((field + 1))
 		done
 	else
 		resolution="$(identify "$file" | sed "s;^$file ;;" | cut --delimiter=' ' --fields=2)"
+		resolution="${resolution%+0+0}"
 	fi
 	export resolution
 }
 
-# link icons in place post-installation from game directory
-# USAGE: icons_linking_postinst $app[…]
-# NEEDED VARS: APP_ID|GAME_ID PATH_GAME PATH_ICON_BASE PKG
-icons_linking_postinst() {
-	# Do nothing if the calling script explicitely asked for skipping icons extraction
-	[ $SKIP_ICONS -eq 1 ] && return 0
-
-	[ "$DRY_RUN" -eq 1 ] && return 0
-	local app
-	local file
-	local icon
-	local list
-	local name
-	local path
-	local path_icon
-	local path_pkg
-	path_pkg="$(get_value "${PKG}_PATH")"
-	if [ -z "$path_pkg" ]; then
-		error_invalid_argument 'PKG' 'icons_linking_postinst'
-	fi
-	path="${path_pkg}${PATH_GAME}"
-	for app in "$@"; do
-		list="$(get_value "${app}_ICONS_LIST")"
-		[ "$list" ] || list="${app}_ICON"
-		name="$(get_value "${app}_ID")"
-		[ "$name" ] || name="$GAME_ID"
-		for icon in $list; do
-			file="$(get_value "$icon")"
-			if version_target_is_older_than '2.8'; then
-				# ensure compatibility with scripts targeting pre-2.8 library
-				if [ -e "$path/$file" ] || [ -e "$path"/$file ]; then
-					icon_get_resolution_from_file "$path/$file"
-				else
-					icon_get_resolution_from_file "${PKG_DATA_PATH}${PATH_GAME}/$file"
-				fi
-			else
-				icon_get_resolution_from_file "$path/$file"
-			fi
-			path_icon="$PATH_ICON_BASE/$resolution/apps"
-			if version_target_is_older_than '2.8' && [ -n "${file##* *}" ]; then
-				cat >> "$postinst" <<- EOF
-				if [ ! -e "$path_icon/$name.png" ]; then
-				  mkdir --parents "$path_icon"
-				  ln --symbolic "$PATH_GAME"/$file "$path_icon/$name.png"
-				fi
-				EOF
-			else
-				cat >> "$postinst" <<- EOF
-				if [ ! -e "$path_icon/$name.png" ]; then
-				  mkdir --parents "$path_icon"
-				  ln --symbolic "$PATH_GAME/$file" "$path_icon/$name.png"
-				fi
-				EOF
-			fi
-			cat >> "$prerm" <<- EOF
-			if [ -e "$path_icon/$name.png" ]; then
-			  rm "$path_icon/$name.png"
-			  rmdir --parents --ignore-fail-on-non-empty "$path_icon"
-			fi
-			EOF
-		done
-	done
-}
-
 # move icons to the target package
 # USAGE: icons_move_to $pkg
+# RETURNS: nothing
+# SIDE EFFECT: move the icons from the current package to the given package
 icons_move_to() {
 	###
 	# TODO
-	# Check that $PKG is set to a valid package
 	# Check that $destination_package is set to a valid package
 	# Check that $PATH_ICON_BASE is set to an absolute path
 	###
@@ -341,23 +342,10 @@ icons_move_to() {
 
 	local source_package      source_path      source_directory
 	local destination_package destination_path destination_directory
-
-	source_package="$PKG"
+	source_package=$(package_get_current)
+	source_directory="$(package_get_path "$source_package")${PATH_ICON_BASE}"
 	destination_package="$1"
-
-	# Get source path, ensure it is set
-	source_path=$(get_value "${source_package}_PATH")
-	if [ -z "$source_path" ]; then
-		error_invalid_argument 'PKG' 'icons_move_to'
-	fi
-	source_directory="${source_path}${PATH_ICON_BASE}"
-
-	# Get destination path, ensure it is set
-	destination_path=$(get_value "${destination_package}_PATH")
-	if [ -z "$destination_path" ]; then
-		error_invalid_argument 'destination_package' 'icons_move_to'
-	fi
-	destination_directory="${destination_path}${PATH_ICON_BASE}"
+	destination_directory="$(package_get_path "$destination_package")${PATH_ICON_BASE}"
 
 	# If called in dry-run mode, return early
 	if [ $DRY_RUN -eq 1 ]; then
