@@ -36,6 +36,7 @@ help() {
 	help_icons
 	help_overwrite
 	help_output_dir
+	help_debug
 
 	# do not print a list of supported archives if called throught the "play.it" wrapper script
 	if [ "$script_name" = 'play.it' ]; then
@@ -44,26 +45,18 @@ help() {
 
 	# print list of supported archives
 	printf 'ARCHIVE\n\n'
-	archives_get_list
 	# shellcheck disable=SC2031
 	case "${LANG%_*}" in
 		('fr')
-			if [ -n "${ARCHIVES_LIST##* *}" ]; then
-				message='Ce script reconnaît lʼarchive suivante :\n'
-			else
-				message='Ce script reconnaît les archives suivantes :\n'
-			fi
+			message='Ce script reconnaît les archives suivantes :'
 		;;
 		('en'|*)
-			if [ -n "${ARCHIVES_LIST##* *}" ]; then
-				message='This script can work on the following archive:\n'
-			else
-				message='This script can work on the following archives:\n'
-			fi
+			message='This script can work on the following archives:'
 		;;
 	esac
-	printf "$message"
-	information_archives_list $ARCHIVES_LIST
+	printf '%s\n' "$message"
+	# shellcheck disable=SC2046
+	information_archives_list $(archives_return_list)
 
 	return 0
 }
@@ -121,27 +114,39 @@ help_checksum() {
 # display --compression option usage
 # CALLED BY: help
 help_compression() {
+	# shellcheck disable=SC2039
 	local message
 	# shellcheck disable=SC2031
 	case "${LANG%_*}" in
 		('fr')
-			message='\tChoix de la méthode de compression des paquets générés\n\n'
-			message="$message"'\t%s\tpas de compression\n'                                     # none
-			message="$message"'\t%s\tcompression gzip (rapide)\n'                              # gzip
-			message="$message"'\t%s\tcompression xz (plus lent mais plus efficace que gzip)\n' # xz
-			message="$message"'\t%s\tcompression bzip2\n\n'                                    # bzip2
+			message='\tChoix de la méthode de compression des paquets générés\n'
+			message="$message"'(Certaines options peuvent ne pas être disponible suivant le format de paquet choisi.)\n\n'
+			message="$message"'\t%s\tpas de compression\n'
+			message="$message"'\t%s\tcompression gzip (rapide)\n'
+			message="$message"'\t%s\tcompression xz (plus lent mais plus efficace que gzip)\n'
+			message="$message"'\t%s\tcompression bzip2\n'
+			message="$message"'\t%s\tcompression zstd\n'
+			message="$message"'\t%s\tcompression lz4 (le plus rapide, mais le plus lourd)\n'
+			message="$message"'\t%s\tcompression lzip (similaire à xz)\n'
+			message="$message"'\t%s\tcompression lzop (plus lent que lz4 à décompresser mais plus efficace)\n\n'
 		;;
 		('en'|*)
-			message='\tGenerated packages compression method selection\n\n'
-			message="$message"'\t%s\tno compression\n'                                       # none
-			message="$message"'\t%s\tgzip compression (fast)\n'                              # gzip
-			message="$message"'\t%s\txz compression (slower but more efficient than gzip)\n' # xz
-			message="$message"'zt%s\tbzip2 compression\n\n'                                  # bzip2
+			message='\tGenerated packages compression method selection\n'
+			message="$message"'(Some options may not be available depending on the chosen package format.)\n\n'
+			message="$message"'\t%s\tno compression\n'
+			message="$message"'\t%s\tgzip compression (fast)\n'
+			message="$message"'\t%s\txz compression (slower but more efficient than gzip)\n'
+			message="$message"'\t%s\tbzip2 compression\n'
+			message="$message"'\t%s\tzstd compression\n'
+			message="$message"'\t%s\tlz4 compression (fastest but biggest files)\n'
+			message="$message"'\t%s\tlzip compression (similar to xz)\n'
+			message="$message"'\t%s\tlzop compression (slower than lz4 at inflating but more efficient)\n\n'
 		;;
 	esac
-	printf -- '--compression=none|gzip|xz|bzip2\n'
-	printf -- '--compression none|gzip|xz|bzip2\n\n'
-	printf "$message" 'none' 'gzip' 'xz' 'bzip2'
+	printf -- '--compression=none|gzip|xz|bzip2|zstd|lz4|lzip|lzop\n'
+	printf -- '--compression none|gzip|xz|bzip2|zstd|lz4|lzip|lzop\n\n'
+	# shellcheck disable=SC2059
+	printf "$message" 'none' 'gzip' 'xz' 'bzip2' 'zstd' 'lz4' 'lzip' 'lzop'
 	return 0
 }
 
@@ -288,3 +293,25 @@ help_output_dir() {
 	return 0
 }
 
+# display --debug option usage
+# USAGE: help_debug
+help_debug() {
+	local message
+
+	#shellcheck disable=SC2031
+	case "${LANG%_*}" in
+		('fr')
+			message='\tDéfinit le niveau de debug. Il vaut 1 par défaut.\n\n'
+			;;
+		('en'|*)
+			message='\tSet the debug level. Default is 1.\n\n'
+			;;
+	esac
+
+	printf -- '--debug\n'
+	printf -- '--debug=N\n'
+	printf -- '--debug N\n\n'
+	printf "$message"
+
+	return 0
+}
