@@ -71,39 +71,79 @@ information_file_integrity_check() {
 # print data extraction message
 # USAGE: information_archive_data_extraction $file
 information_archive_data_extraction() {
+	# shellcheck disable=SC2039
 	local message file
 	file="$1"
 	# shellcheck disable=SC2031
 	case "${LANG%_*}" in
 		('fr')
-			message='Extraction des données de %s'
+			message='Extraction des données de %s…\n'
 		;;
 		('en'|*)
-			message='Extracting data from %s'
+			message='Extracting data from %s…\n'
 		;;
 	esac
+	# shellcheck disable=SC2059
 	printf "$message" "$file"
 	return 0
 }
 
+# print data extraction success message
+# USAGE: information_archive_data_extraction_done
+information_archive_data_extraction_done() {
+	# shellcheck disable=SC2039
+	local message
+	# shellcheck disable=SC2031
+	case "${LANG%_*}" in
+		('fr')
+			message='Extraction réussie !'
+		;;
+		('en'|*)
+			message='Extraction done!'
+		;;
+	esac
+	printf '%s\n' "$message"
+	return 0
+}
+
 # print package building message
 # USAGE: information_package_building $file
 information_package_building() {
+	# shellcheck disable=SC2039
 	local message file
 	file="$1"
 	# shellcheck disable=SC2031
 	case "${LANG%_*}" in
 		('fr')
-			message='Construction de %s'
+			message='Construction de %s…\n'
 		;;
 		('en'|*)
-			message='Building %s'
+			message='Building %s…\n'
 		;;
 	esac
+	# shellcheck disable=SC2059
 	printf "$message" "$file"
 	return 0
 }
 
+# print package building message
+# USAGE: information_package_building $file
+information_package_building_done() {
+	# shellcheck disable=SC2039
+	local message
+	# shellcheck disable=SC2031
+	case "${LANG%_*}" in
+		('fr')
+			message='Contruction terminée !'
+		;;
+		('en'|*)
+			message='Building done!'
+		;;
+	esac
+	printf '%s\n' "$message"
+	return 0
+}
+
 # print notification about required overlays when building Gentoo packages
 # USAGE: information_required_gentoo_overlays $overlays
 information_required_gentoo_overlays() {
@@ -195,18 +235,80 @@ info_archive_integrity_check() {
 # print hash computation message
 # USAGE: info_archive_hash_computation $file
 info_archive_hash_computation() {
+	# shellcheck disable=SC2039
 	local file message
 	file=$(basename "$1")
 	# shellcheck disable=SC2031
 	case "${LANG%_*}" in
 		('fr')
-			message='Calcul de la somme de contrôle de %s'
+			message='Calcul de la somme de contrôle de %s…\n'
 		;;
 		('en'|*)
-			message='Computing hashsum for %s'
+			message='Computing hashsum for %s…\n'
 		;;
 	esac
+	# shellcheck disable=SC2059
 	printf "$message" "$file"
 	return 0
 }
 
+# print hash computation success message
+# USAGE: info_archive_hash_computation_done
+info_archive_hash_computation_done() {
+	# shellcheck disable=SC2039
+	local message
+	# shellcheck disable=SC2031
+	case "${LANG%_*}" in
+		('fr')
+			message='Somme de contrôle calculée !'
+		;;
+		('en'|*)
+			message='Hashsum computed!'
+		;;
+	esac
+	printf '%s\n' "$message"
+	return 0
+}
+
+# inform the need of a local overlay on gentoo for ebuilds
+# USAGE: info_local_overlay_gentoo
+info_local_overlay_gentoo() {
+	# shellcheck disable=SC2039
+	local message
+	# shellcheck disable=SC2031
+	case "${LANG%_*}" in
+		('fr')
+			message='\nUn overlay local est nécessaire pour utiliser les ebuilds générés par ./play.it\n'
+			message="$message"'Dans la suite OVERLAY_PATH correspond au chemin de votre overlay local\n'
+		;;
+		('en'|*)
+			message='\nA local overlay is needed to use the ebuilds generated by ./play.it\n'
+			message="$message"'In what comes next, OVERLAY_PATH is the path to your local overlay\n'
+		;;
+	esac
+	# shellcheck disable=SC2059
+	printf "$message"
+	return 0
+}
+
+# inform the need to move the packages to a distfile on egentoo
+# USAGE: info_package_to_distfiles
+info_package_to_distfiles() {
+	# shellcheck disable=SC2039
+	local message
+	# shellcheck disable=SC2031
+	case "${LANG%_*}" in
+		('fr')
+			message='Déplacez les paquets créés dans votre disfile\n'
+			message="$message"'puis exécutez les instructions suivantes :\n'
+			;;
+		('en'|*)
+			message='Move the generated packages into your distfile\n'
+			message="$message"'then run the following commands:\n'
+			;;
+	esac
+	# shellcheck disable=SC2059
+	printf "$message"
+	return 0
+}
+
